@@ -41,8 +41,8 @@ class Lexer:
                     close_parentheses_count += 1
                     lexed_token_list.append(token)
                 else:
-                    lexed_token_list.append(']')
-                    lexed_token_list.append('[')
+                    lexed_token_list.append('}')
+                    lexed_token_list.append('{')
             elif token[0] in digit_set:
                 # Normal numeric operand
                 num = float(token) if '.' in token else int(token)
