@@ -30,6 +30,8 @@ class Tree:
                 self.currentPointer = node
         else:
             if node > self.currentPointer:
+                node.parent = self.currentPointer
+                self.currentPointer.children[-1].parent = node
                 node.children.append(self.currentPointer.children.pop())
                 self.currentPointer.children.append(node)
                 self.currentPointer = node
@@ -46,6 +48,8 @@ class Tree:
             self.currentPointer = self.currentPointer.parent
             self.float_node(node=node)
         else:
+            node.parent = self.currentPointer
+            self.currentPointer.children[-1].parent = node
             node.children.append(self.currentPointer.children.pop())
             self.currentPointer.children.append(node)
             self.currentPointer = node
@@ -53,6 +57,7 @@ class Tree:
     def reset(self):
         self.root = None
         self.currentPointer = None
+        return self
 
     def update_values(self, node: Node):
         for c in node.children:
@@ -67,7 +72,8 @@ class Tree:
                                  ) + (len(node.children) - 1) * self.padding
             node.width = max(node.inner_width, node.sub_width)
             node.height = max(map(lambda n: n.height, node.children)) + 1
-            node.bal_coef = node.get_balance_coefficient()
+            if node.inner_width <= node.sub_width:
+                node.bal_coef = node.get_balance_coefficient()
 
     def update_paddings(self, node: Node):
         if node.parent is not None:
@@ -121,7 +127,7 @@ class Tree:
                 self.update_dims(node=self.root)
                 self.reset_paddings(node=self.root)
                 self.update_paddings(node=self.root)
-            if which not in ['all', 'dimensions', 'values']:
+            if which not in {'all', 'dimensions', 'values'}:
                 raise UpdateTreeError(
                     f'Unexpected value \'{which}\' for \'which\' parameter encountered')
 
