@@ -11,12 +11,12 @@ def variable_speed_print(message: str,
                          seconds_per_char: Union[int, float] = 0,
                          space_ratio: Union[int, float] = 0.1,
                          seconds_newline: Union[int, float] = 0) -> None:
-    for char in message:
-        print(char, end='', flush=True)
-        if char == '\n':
+    for i, char in enumerate(message):
+        if char == '\n' and i < len(message) - 1 and message[i + 1] == '\n':
             sleep(seconds_newline)
         elif char == ' ':
             sleep(seconds_per_char * space_ratio)
         else:
             sleep(seconds_per_char)
+        print(char, end='', flush=True)
     print()
